@@ -4,9 +4,6 @@ __all__ = [
     'NotebookExecutorBase',
     'InMemoryQueryExecutorBase',
     'FeatureComputeBase',
-    'FeatureExtractorBase',
-    'FeaturesetExtractorBase',
-    'note',
     'MetricsBase'
 ]
 
