@@ -130,7 +130,7 @@ class InMemoryQueryExecutorBase(Compute):
         """
 
         # Collect specs first..
-        specs = self.get_specs()
+        specs = self.get_sql_specs()
 
         # Compute the targets
         targets = ['all'] #default
@@ -280,7 +280,7 @@ class InMemoryQueryExecutorBase(Compute):
         # Default...
         raise Exception(f"Unknown duration: {duration}")
 
-    def get_specs(self):
+    def get_sql_specs(self):
         """
         Return a list of query specifications.
 
@@ -314,7 +314,19 @@ class InMemoryQueryExecutorBase(Compute):
              },
 
         """
-        pass
+
+        self.get_specs()
+
+    def get_specs(self):
+        """
+        Use get_sql_specs instead.
+
+        .. warning::
+            .. deprecated:: 2.6.0
+
+        """
+
+        return []
 
     def get_engine(self, spec):
         """
@@ -379,7 +391,7 @@ class InMemoryQueryExecutorBase(Compute):
         targets = self.args['targets']
 
         # Get specs..
-        specs = self.get_specs()
+        specs = self.get_sql_specs()
 
         logger.debug(f"Specs found: {len(specs)}",
                      extra={
