@@ -26,9 +26,9 @@ class RunBase(object):
         Initialize the Run class
 
         Args:
-
             config (object): Pipeline execution object
             rundir (str): Directory with runs
+
         """
         self.config = kwargs.pop('config')
         self.rundir = kwargs.pop('rundir')
@@ -295,7 +295,7 @@ class RunBase(object):
 
     def load(self):
         """
-        Load the metadata and other aspects of run
+        Load the metadata and compute lineage
         """
         self.load_metadata()
         try:
@@ -309,7 +309,7 @@ class RunBase(object):
 
     def compute_compliance_metadata(self):
         """
-        Collect the column information from each of the frames
+        Collect the column information from each of the frames adnd generate 
         """
         frames = {}
 
@@ -409,7 +409,6 @@ class RunBase(object):
             else:
                 columns = columns_default
 
-
             # => Now collect all the information in a single dict We
             # know for each frame, what the columns are, what was the
             # input and what was the output.
@@ -543,6 +542,8 @@ class RunBase(object):
 
                 root = self.config.enrich_data_dir
                 path = os.path.join(root, component['filename'])
+                if not os.path.exists(path):
+                    path = component['filename']
                 frametype = p.get('frametype', 'pandas')
 
                 detail = copy.copy(component)
