@@ -11,6 +11,7 @@ provides:
 import os
 import sys
 import platform
+import distro
 import resource
 import psutil
 import nbformat
@@ -104,7 +105,7 @@ class Notebook(object):
                 'release': platform.release(),
                 'processor': platform.processor(),
                 'python': platform.python_version(),
-                'distribution': platform.linux_distribution()
+                'distribution': distro.linux_distribution()
                 }
         metadata["filename"] = filename
         metadata["filetype"] = mimetypes.guess_type(filename)[0]
