@@ -28,7 +28,7 @@ class CustomEncoder(json.JSONEncoder):
         except:
             return str(obj)
 
-logger = logging.getLogger()
+logger = logging.getLogger('app')
 
 class MockRun(object):
 
@@ -288,7 +288,7 @@ class MockConfig(object):
 
 
     def get_usecase(self):
-        return self.usecase
+        return self.usecase.get("org",{}).get("name","Unknown")
 
     def get_customer(self):
         return self.get_usecase()
@@ -500,6 +500,7 @@ class MockConfig(object):
                     }
                     for k, v in args.items()
                 ]
+
         testdata = testdata.get('data',{})
         for framename, details in testdata.items():
             stages = details.get('stages',[])
@@ -508,6 +509,7 @@ class MockConfig(object):
             # We could have potentially specified multiple files that need to be loaded
             paths = []
             transform = details['transform']
+            sources = []
             if 'source' in details:
                 source = details['source']
             else:
@@ -515,6 +517,7 @@ class MockConfig(object):
             if isinstance(source, str):
                 if "inputdir" not in source:
                     source = "%(inputdir)s/%(transform)s/" + source
+                sources.append(source)
                 path = self.get_file(source, extra={
                     'inputdir': self.inputdir,
                     'transform': transform
@@ -524,6 +527,7 @@ class MockConfig(object):
                 for f in source:
                     if 'inputdir' not in f:
                         f = "%(inputdir)s/%(transform)s/" + f
+                    sources.append(f)
                     path = self.get_file(f, extra={
                         'inputdir': self.inputdir,
                         'transform': transform
@@ -532,6 +536,7 @@ class MockConfig(object):
             elif isinstance(source, dict):
                 for group in source:
                     for f in source[group]:
+                        sources.append(f)
                         path = self.get_file(f, extra={
                             'transform': transform,
                             'group': group
@@ -539,7 +544,10 @@ class MockConfig(object):
                         paths.extend(glob.glob(path))
 
             if len(paths) == 0:
-                logger.warning("No files to load for {}".format(framename))
+                logger.warning("No files to load for {}".format(framename),
+                               extra={
+                                   'data': "Searched " + ",".join(sources)
+                               })
                 continue
 
             _dfs = []
